@@ -23,6 +23,9 @@ typedef struct r_buf_t {
 	// RIOBind *iob;
 	// forward declaration
 	void *iob;
+	ut64 offset;
+	ut64 limit;
+	struct r_buf_t * parent;
 } RBuffer;
 
 typedef struct r_buf_cache_t {
@@ -36,6 +39,7 @@ typedef struct r_buf_cache_t {
 
 /* constructors */
 R_API RBuffer *r_buf_new(void);
+R_API RBuffer *r_buf_new_with_io(void *iob, int fd);
 R_API RBuffer *r_buf_new_with_bytes(const ut8* bytes, ut64 len);
 R_API RBuffer *r_buf_new_with_string (const char *msg);
 R_API RBuffer *r_buf_new_with_pointers(const ut8 *bytes, ut64 len);
@@ -45,6 +49,7 @@ R_API RBuffer *r_buf_new_slurp(const char *file);
 R_API RBuffer *r_buf_new_empty (ut64 len);
 R_API RBuffer *r_buf_mmap(const char *file, int flags);
 R_API RBuffer *r_buf_new_sparse(ut8 Oxff);
+R_API RBuffer *r_buf_new_slice(RBuffer *b, ut64 offset, ut64 size);
 R_API bool r_buf_dump (RBuffer *buf, const char *file);
 R_API RBuffer *r_buf_ref(RBuffer *b);
 /* methods */
@@ -69,6 +74,7 @@ R_API int r_buf_fread_at(RBuffer *b, ut64 addr, ut8 *buf, const char *fmt, int n
 R_API int r_buf_write_at(RBuffer *b, ut64 addr, const ut8 *buf, int len);
 R_API int r_buf_fwrite_at(RBuffer *b, ut64 addr, ut8 *buf, const char *fmt, int n);
 R_API void r_buf_free(RBuffer *b);
+R_API bool r_buf_fini(RBuffer *b);
 R_API char *r_buf_free_to_string(RBuffer *b);
 R_API const ut8 *r_buf_buffer(RBuffer *b);
 R_API ut64 r_buf_size(RBuffer *b);
